@@ -110,7 +110,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         models.append(model)
         gc.collect()
         
-        list_train_score.append(kpi["train/average_precision"])
+        
         
         list_train_precision.append(kpi["train/precision"])
         list_train_recall.append(kpi["train/recall"])
@@ -133,7 +133,8 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         #list_FP_train_opt.append(kpi["train/FP_opt"])  
         #list_TN_train_opt.append(kpi["train/TN_opt"])  
         #list_FN_train_opt.append(kpi["train/FN_opt"]) 
-
+        
+        list_train_score.append(kpi["train/score"])
         list_valid_score.append(kpi["valid/score"])
         
         list_valid_precision.append(kpi["valid/precision"])
@@ -391,20 +392,22 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
     d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=cat_features, params=dataset_params)
     d_valid = lgb.Dataset(X_valid, label=y_valid, categorical_feature=cat_features, params=dataset_params)
 
-    watchlist = [d_valid]    
+    watchlist = [d_train,d_valid]    
 
     
+    pruning_callback_t = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_train")    
     pruning_callback_v = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_valid")
-    
+
     model = lgb.train(train_params,                 
                       num_boost_round = num_rounds,
                       train_set=d_train,
-                      valid_names = ['data_valid'],
+                      valid_names = ['data_train','data_valid'],
                       valid_sets=watchlist,
                       feval=lgb_f1_score,
-                      callbacks=[log_evaluation(log),pruning_callback_v,early_stopping(early_stop)]
+                      callbacks=[log_evaluation(log),pruning_callback_t,pruning_callback_v,early_stopping(early_stop)]
                      )
     
+    train_best_score = model.best_score['data_train'][metric]
     valid_best_score = model.best_score['data_valid'][metric]
 
     # predictions
@@ -444,7 +447,7 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
     roc_auc = roc_auc_score(y_valid, y_pred_prob_valid) 
     
 
-    bias = train_average_precision - valid_average_precision    
+    bias = train_best_score - valid_best_score    
  
     kpi = {'train/average_precision': train_average_precision,  
            'train/precision': precision_t,
@@ -463,7 +466,7 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
            #'train/FP_opt': FP_train_opt,   
            #'train/TN_opt': TN_train_opt,   
            #'train/FN_opt': FN_train_opt,  
-           
+           'train/score': train_best_score,
            'valid/score': valid_best_score,
            
            'valid/average_precision': valid_average_precision,
